#
# spec file for package spandsp
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           spandsp
%define lname	libspandsp3
Version:        3.0.0+g21
Release:        1.3
Summary:        A DSP library for Telephony and SoftFAX
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            https://github.com/freeswitch/spandsp

Source:         %name-%version.tar.xz
Source2:        baselibs.conf
Patch1:         no-sse.diff
Patch2:         spandsp-raise-traintime-tolerance.diff
Patch3:         spandsp-handle-international-dialstring-prefix.diff
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  doxygen
BuildRequires:  libjpeg-devel
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  pkg-config
%define tests 0
%if 0%{?tests}
BuildRequires:  fftw3-devel
BuildRequires:  fltk-devel
BuildRequires:  gcc-c++
BuildRequires:  libpcap-devel
BuildRequires:  pkgconfig(audiofile)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(xproto)
%endif

%description
SpanDSP is a library of DSP functions for telephony, in the 8000 sample
per second world of E1s, T1s, and higher order PCM channels. It
contains low level functions, such as basic filters. It also contains
higher level functions, such as cadenced supervisory tone detection,
and a complete software FAX machine.

%package devel
Summary:        Development files for the SpanDSP library
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libjpeg-devel
Requires:       libtiff-devel

%description devel
This package contains files that are needed for developing or compiling
software that uses the spandsp library.

%package -n %lname
Summary:        A DSP library for Telephony and SoftFAX
License:        LGPL-2.1-only
Group:          System/Libraries

%description -n %lname
SpanDSP is a library of DSP functions for telephony, in the 8000 sample
per second world of E1s, T1s, and higher order PCM channels. It
contains low level functions, such as basic filters. It also contains
higher level functions, such as cadenced supervisory tone detection,
and a complete software FAX machine.

%package doc
Summary:        Documentation for the libspandsp API
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package contains documentation for the libspandsp API.

%prep
%autosetup -p1
# The cpuid calls in the source code only apply to a test program.
# The library itself is (was) statically enabling -msse during configure, which
# is now removed.

%build
autoreconf -fiv
%configure \
	--disable-static \
	--enable-doc
%make_build

%check
%if 0%{?tests}
%make_build check
%endif

%install
%make_install
mkdir -p "%buildroot%_docdir/%name"
cp -a NEWS README DueDiligence ChangeLog doc/api/html \
	"%buildroot/%_docdir/%name"
rm -f "%buildroot/%_libdir"/*.la
ln -s ../spandsp.h "%buildroot/%_includedir/spandsp/spandsp.h"

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files devel
%license COPYING
%_includedir/*
%_libdir/lib%name.so
%_libdir/pkgconfig/*.pc

%files -n %lname
%_libdir/lib%name.so.3*

%files doc
%_docdir/%name/

%changelog
* Sun Jun 25 2023 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 3.0.0+g21 (0d2e6ac6)
  * Ensure we never copy too much from pitch_overlap
    to the output buffer.
* Tue Mar 28 2023 Martin Liška <mliska@suse.cz>
- Enable LTO as it builds with now (boo#1136056).
* Mon Apr 18 2022 Jan Engelhardt <jengelh@inai.de>
- Add no-sse.diff
* Sat Apr  2 2022 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 3.0.0.g15
  * Add ARMv7 NEON support
  * Add V.32bis and V.34 support
- Remove spandsp-autoconf.diff
* Sun Sep  6 2020 Jan Engelhardt <jengelh@inai.de>
- More specfile modernization.
* Mon Sep  9 2019 Jan Engelhardt <jengelh@inai.de>
- Modernized the specfile.
* Thu May 23 2019 Martin Liška <mliska@suse.cz>
- Disable LTO (boo#1136056).
* Tue Sep 11 2018 Hans-Peter Jansen <hpj@urpla.net>
- add patch spandsp-handle-international-dialstring-prefix.diff
  in order to support the international dialing prefix
* Mon Sep 10 2018 Hans-Peter Jansen <hpj@urpla.net>
- apply patch spandsp-raise-traintime-tolerance.diff
  as supplied with iaxmodem
* Wed Mar 25 2015 p.drouand@gmail.com
- Update to version 0.0.6 (finale)
  * Unupdated changelog
- Remove obsolete patches
  * spandsp-pkgconfig1.diff
  * spandsp-path.diff
  * spandsp-lrint.diff
- Update spandsp-autoconf.diff
- Use download Url as source
- Remove xz require
* Fri Jan 25 2013 jengelh@inai.de
- Update to new upstream release 0.0.6pre21
  * No upstream changelog has been specified
* Sun Mar 11 2012 jengelh@medozas.de
- Update to new upstream release 0.0.6pre20
  * No upstream changelog has been specified
  * Protect against T.38 stuff arriving after document has finished
* Sun Mar 11 2012 jengelh@medozas.de
- License clarifications (bnc#731943)
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Oct 27 2011 kkeil@linux-pingi.de
- Upstream did change the license to LGPL 2.1 in 2008
* Sat Oct  8 2011 jengelh@medozas.de
- updated to new upstream release 0.0.6pre18
  * no changelog was provided by upstream
- put documentation into its own subpackage
- enable SSE2 on x86_64, since it's part of the x86_64 ABI anyway
- add patches to resolve autoconf warnings (spandsp-autoconf.diff),
  failure to properly find lrint (spandsp-lrint.diff), a typo
  (spandsp-path.diff), and faulty dependencies
  (spandsp-pkgconfig1.diff)
- Separate build and test dependencies
- Enable parallel build
* Sat Mar 13 2010 chris@computersalat.de
- added baselibs.conf
- cleanup spec
  o sort TAGS
  o fix build warnig
    build without RPM_OPT_FLAGS
  o macro usage
  o removed data from changelog
* Wed Sep 24 2008 ro@suse.de
- fix debug package requires again
* Wed Sep 17 2008 mrueckert@suse.de
- fix requires of the debug package
* Thu Sep 11 2008 max@suse.de
- New version: 0.0.5pre4
- Packages renamed to comply with the package naming conventions.
- Added libxslt and docbook-xsl-stylesheets to build the
  T.34 documentation.
* Fri May  2 2008 crrodriguez@suse.de
- fix Error: shlib-with-non-pic-code /usr/lib/libspandsp.so.0.0.2 in PPC
  _ some files not built with RPM_OPT_FLAGS
* Mon Feb 25 2008 crrodriguez@suse.de
- fix library-without-ldconfig*  errors
- fix -devel package dependencies
* Wed Jan 23 2008 max@suse.de
- New version: 0.0.4pre16
- It is said to be more stable for faxing (#347599).
- Added API documentation to the devel subpackage.
- Enabled MMX for i586 and i686.
- Removed the static library.
* Thu Aug  2 2007 max@suse.de
- Update to final 0.0.3 version (obsoletes our previous patches)
- Split off a devel package
* Tue Mar 13 2007 pgajdos@suse.cz
- fixed 'warning: array subscript is above array bounds' (#239958)
- array-subscript.patch
* Fri Oct 20 2006 max@suse.de
- New version: 0.0.3pre24
- Improved fax handling.
* Mon Mar 20 2006 max@suse.de
- New version: 0.0.2pre25
- fixed an error in T.4 processing, causing a sideways shift with some
  sending FAX machines (e.g. some Canons).
- fixed an error in the generation of single tones.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 max@suse.de
- New version: 0.0.2pre23
* Fri Dec 16 2005 max@suse.de
- New version: 0.0.2pre21
* Mon May 23 2005 max@suse.de
- New version: 0.0.2pre18
* Wed May  4 2005 max@suse.de
- New version: 0.0.2pre17
* Fri Apr 22 2005 max@suse.de
- New version: 0.0.2pre15
- Fixed building with gcc4 and reduced warnings.
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Mon Feb 28 2005 max@suse.de
- New version: 0.0.2pre10
* Mon Feb 28 2005 max@suse.de
- New version: 0.0.2pre9
* Thu Jan 13 2005 max@suse.de
- New version: 0.0.2pre8
* Wed Jan 12 2005 max@suse.de
- New version: 0.0.2pre7
* Mon Nov 29 2004 max@suse.de
- New version: 0.0.2pre6
* Thu Nov 18 2004 ro@suse.de
- fixed file list
* Fri Nov  5 2004 max@suse.de
- New version: 0.0.2pre4
* Tue Jul  6 2004 max@suse.de
- autoreconf needs --install to get the names of shared libs right.
* Mon Jul  5 2004 max@suse.de
- Don't use x86-speciffic assembler code.
* Wed Jun 23 2004 max@suse.de
- New package: spandsp (0.0.1k)
- SpanDSP is a library of DSP functions for telephony, in the
  8000 sample per second world of E1s, T1s, and higher order
  PCM channels. It contains low level functions, such as basic
  filters. It also contains higher level functions, such as
  cadenced supervisory tone detection, and a complete software
  FAX machine.
